@@ -14,18 +14,27 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from ipydrawio.constants import IPYNB_METADATA
+
 # the header to look for in PNG metadata
 PNG_DRAWIO_INFO = "mxfile"
 
 # TODO: hoist this to `package.json` and consume directly
 DRAWIO_APP = "../labextensions/@deathbeds/ipydrawio-webpack/static/dio"
 
-# key set in notebook#/metadata/
-IPYNB_METADATA = "@deathbeds/ipydrawio"
-
 # environment variables
 ENV_JUPYTER_DATA_DIR = "JUPYTER_DATA_DIR"
 ENV_IPYDRAWIO_DATA_DIR = "IPYDRAWIO_DATA_DIR"
 
 # always appended to *_DATA_DIR
 WORK_DIR = "ipydrawio_export"
+
+
+__all__ = [
+    "IPYNB_METADATA",
+    "PNG_DRAWIO_INFO",
+    "DRAWIO_APP",
+    "ENV_JUPYTER_DATA_DIR",
+    "ENV_IPYDRAWIO_DATA_DIR",
+    "WORK_DIR",
+]
